@@ -5,11 +5,11 @@ function (silentQ = FALSE)
         stop("`.UserDirectory` or `.UserDate` not defined. See help(rwm).")
     setwd(.UserDirectory)
     rm(list = ls(envir = .GlobalEnv), envir = .GlobalEnv)
-    if (exists(".WSID", where=1)) 
+    if (exists(".WSID", where=1, inherits=FALSE)) 
         rm(".WSID", envir = .GlobalEnv)
-    if (exists(".LastSaved", where=1)) 
+    if (exists(".LastSaved", where=1, inherits=FALSE)) 
         rm(".LastSaved", envir = .GlobalEnv)
-    if (exists(".Describe", where=1)) 
+    if (exists(".Describe", where=1, inherits=FALSE)) 
         rm(".Describe", envir = .GlobalEnv)
     if (!silentQ) {
         cat("Workspace cleared.", fill = TRUE)
